/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfview;

import android.content.Context;
import android.util.AttributeSet;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.compdfkit.core.document.CPDFDocument;


public class CPDFReaderView extends FrameLayout {

    private com.compdfkit.ui.reader.CPDFReaderView cPdfReaderView;

    public CPDFReaderView(@NonNull Context context) {
        super(context);
        initCPDFReaderView();
    }

    public CPDFReaderView(@NonNull Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        initCPDFReaderView();
    }

    public CPDFReaderView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
    }


    private void initCPDFReaderView() {
        cPdfReaderView = new com.compdfkit.ui.reader.CPDFReaderView(getContext());
        addView(cPdfReaderView);
    }


    /**
     * This method opens a PDF file located at the given file path.
     *
     * @param pdfFilePath The file path of the PDF file to be opened.
     */
    public void openPdfFile(String pdfFilePath) {
        // Create a new instance of the CPDFDocument class, passing in the current context.
        CPDFDocument cpdfDocument = new CPDFDocument(getContext());
        // Attempt to open the PDF file at the given file path using the open method of the CPDFDocument class.
        CPDFDocument.PDFDocumentError pdfDocumentError = cpdfDocument.open(pdfFilePath);
        // Switch on the result of the open method to handle the different possible outcomes.
        switch (pdfDocumentError) {
            // If the PDF file was successfully opened, set the PDF document of the CPdfReaderView instance to the opened document.
            case PDFDocumentErrorSuccess:
                cPdfReaderView.setPDFDocument(cpdfDocument);
                break;
            // If the PDF file requires a password to be opened, do nothing for now.
            case PDFDocumentErrorPassword:

                break;
            // For all other errors, do nothing for now.
            default:
                break;
        }
    }


}
